@@ -45,7 +45,7 @@
       <link rel="stylesheet" type="text/css" href="bacula.css" title="blueish">
       <meta name="Description" content="Bacula a network backup and restore program">
       <meta name="Keywords" content="Bacula, backup, restore, file backup">
-      <meta name="Copyright" content="Copyright (C) 2000-2006 Kern Sibbald">
+      <meta name="Copyright" content="Copyright (C) 2000-2007 Kern Sibbald">
       <meta name="Trademark" content="Bacula (R) is a registered trademark of John Walker">
    </head>
 
@@ -117,7 +117,7 @@
            <li class="menuItem"> <a href="dev-manual/Supported_Tape_Drives.html"> Tapedrives </a> </li>
            <li class="menuItem"> <a href="dev-manual/Supported_Autochangers.html"> Autochangers </a> </li>
            <li class="menuItem"> <a href="dev-manual/Bacula_Copyri_Tradem_Licens.html"> License </a> </li>
-           <li class="menuItem"> <a href="FLA-bacula.en.pdf"> FSFE License </a></li>
+           <li class="menuItem"> <a href="<? echo $spath ?>/?page=fsfe"> FSFE License </a></li>
            </ul>
         </div>
 
@@ -127,7 +127,9 @@
         <div class="menuItem">
            <ul class="menuitem">
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=documentation"> Documentation </a></li>
+           <li class="menuItem"> <a href="http://wiki.bacula.org">Wiki </a></li>
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=presentations"> Presentations </a></li>
+           <li class="menuItem"> <a href="<? echo $spath ?>/?page=presskits"> Press Kits </a></li>
            </ul>
         </div>
 
@@ -137,7 +139,7 @@
            <ul class="menuitem">
            <li class="menuItem"> <a href="http://sourceforge.net/project/showfiles.php?group_id=50727"> Current Files </a> </li>
            <li class="menuItem"> <a href="http://sourceforge.net/project/showfiles.php?group_id=50727#files"> All Files </a> </li>
-           <li class="menuItem"> <a href="http://sourceforge.net/cvs/?group_id=50727"> CVS Repository </a> </li>
+           <li class="menuItem"> <a href="http://sourceforge.net/svn/?group_id=50727"> SVN Repository </a> </li>
            </ul>
         </div>
 
@@ -156,21 +158,25 @@
         <!-- Projects -->
         <div class="menuHead"> Projects </div>
         <div class="menuItem">
-           <ul class="menuitem"
+           <ul class="menuitem">
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=projects"> Projects </a> </li>
+  <!--
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=vote"> Project Vote </a> </li>
+  -->
            </ul>
         </div>
 
-        <!-- Donations -->
         <div class="menuHead"> Donations </div>
         <div class="menuItem">
            <ul class="menuitem">
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=makedonation"> Make a Donation </a> </li>
+  <!--
            <li class="menuItem"> <a href="<? echo $spath ?>/?page=donations"> Donations Received </a> </li>
+  -->
            </ul>
         </div>
 
+
         <div class="menuHead">
         <div class="icons">
            <a href="http://www.sectoor.de"><img src="http://www.sectoor.de/grafiken/button_klein2.png" alt="Sectoor Logo"></a>
