@@ -122,6 +122,34 @@
               </td>
       </tr>
 
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr> <td colspan="3"><hr></td>
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr>
+              <td style="font-weight: bold">
+                      dass IT GmbH
+              </td>
+              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
+              <td>
+                 <a href="mailto:infoNSPAM@dass-it.de">dass IT GmbH</a><br>
+                 H&auml;ndelstra&#223;e 25-29<br>
+                 50674 K&ouml;ln<br>
+                 Germany<br>
+                 Tel: +49 221 35 65 666 - 0<br>
+                 Fax: +49 221 35 65 666 - 10<br>
+                 <br>
+                 dass IT provides professional services and
+                 support using mainly open source tools.  Our
+                 focus lies on system management for a large
+                 number of systems (servers and desktops).  We
+                 provide services and solutions mainly for Linux
+                 based IT infrastructures.  
+                 <br> 
+                 <a href="http://www.dass-it.de/">http://www.dass-it.de/</a>
+              </td>
+      </tr>
+
+
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
       <tr> <td colspan="3"><hr></td>
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
@@ -217,7 +245,7 @@
               <td>
                  <a href="mailto:l.strappazonNOSPAM@free.fre">Ludovic Strappazon</a><br>
                  Strasbourg, France<br>
-                 +33 660 954735 <br>
+                 +33 685 27 93 39<br>
                  <br>
                  I offer engineering services and training around storage and Backup. 
                  Planning and scaling of your hardware installation, Bacula implementation.
@@ -269,8 +297,9 @@
                  solutions, based on Open Source software, help
                  you run your servers and applications
                  failure-free.  Special focus on Nagios, Bacula,
-                 Request Tracker, and cluster solutions.  <br> <a
-                 href="http://www.netways.de">http://www.netways.de</a><br>
+                 Request Tracker, and cluster solutions.  <br> 
+                 <br>
+                 <a href="http://www.netways.de">http://www.netways.de</a><br>
               </td>
       </tr>
 
@@ -295,7 +324,7 @@
                  <br>
                  Modern communications, Internet projects and IT services since 1996!
                  Specialized in heterogeneous networks (linux, mac, windows) and open 
-                 source solutions.
+                 source solutions.<br>
                  <br>
                  <a href="http://www.raptus.com">http://www.raptus.com</a><br>
               </td>
@@ -331,6 +360,32 @@
                  <a href="http://www.sinenomine.net">http://www.sinenomine.net</a><br>
               </td>
       </tr>
+
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr> <td colspan="3"><hr></td>
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr>
+              <td style="font-weight: bold">
+                      Thinxsolutions 
+              </td>
+              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
+              <td>
+                 <a href="mailto:infoNOSPAM@thinxsolutions.com">
+                 M&uuml;ller, Bender, Guth GbR</a><br>
+                 &nbsp;&nbsp;Maarweg 139 <br>
+                 &nbsp;&nbsp;50825 Cologne, Germany <br>
+                 <br>
+                 &nbsp;&nbsp;+49 221 35503530<br>
+                 <br>
+                 We implement and manage corporate networks for our customers
+                 and offer consulting and professional support for various open source
+                 software solutions.<br>
+                 <br>
+                 <a href="http://www.thinxsolutions.com">http://www.thinxsolutions.com</a><br>
+              </td>
+      </tr>
+
+
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
       <tr> <td colspan="3"><hr></td>
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
@@ -351,6 +406,7 @@
                  (Spamassassin/Amavis/Clamav/BitDefender)
                  and backup (with Bacula of course). Network monitoring with Nagios.
                  <br>
+                 <br>
                  <a href="http://www.WinFix.IT">http://www.WinFix.IT</a><br>
               </td>
       </tr>
